FlutterMetaAppadsSdkWeb class

Inheritance

Constructors

FlutterMetaAppadsSdkWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFbAnonId() Future<FBAnonIdResponse?>
override
initSdk({bool enableLogging = false}) Future<void>
override
initWebPixel({required String pixelId, String locale = 'en_US', bool autoLogPageView = true}) Future<void>
override
logEvents(FBLogEventRequest request) Future<void>
override
logPurchase(FBLogPurchaseRequest request) Future<void>
override
logStandardEvent(FBLogStandardEventRequest request) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdvertiserIDCollectionEnabled({required bool isEnabled}) Future<void>
override
setAdvertiserTrackingEnabled({required bool isEnabled}) Future<void>
override
setAutoLogAppEventsEnabled({required bool isEnabled}) Future<void>
override
setDataProcessingOptions(FBSetDataProcessingOptionsRequest request) Future<void>
override
setUserData(FBSetUserDataRequest request) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void